'use client';

import { dummyPosts } from '@/app/constants/blogPosts';
import { Box, Heading, VStack, Text, Link as ChakraLink } from '@chakra-ui/react';
import Link from 'next/link';

interface RelatedProps {
  currentSlug: string;
}

export default function PostDetailPageRelatedPosts({ currentSlug }: RelatedProps) {
  const relatedPosts = dummyPosts
    .filter(post => post.slug !== currentSlug)
    .slice(0, 3); // Show 3 related posts

  return (
    <Box mt={10}>
      <Heading size="md" mb={4}>Related Posts</Heading>
      <VStack spacing={4} align="stretch">
        {relatedPosts.map(post => (
          <Box key={post.id} p={4} bg="gray.50" borderRadius="md" shadow="sm">
            <Link href={`/blog/${post.slug}`} passHref>
              <ChakraLink fontSize="lg" fontWeight="bold" color="blue.500">
                {post.title}
              </ChakraLink>
            </Link>
            <Text fontSize="sm" color="gray.600">
              {post.excerpt.slice(0, 80)}...
            </Text>
          </Box>
        ))}
      </VStack>
    </Box>
  );
}
